library dio_config;

import 'package:dio/dio.dart';
import 'package:shared_preferences/shared_preferences.dart';

class DioConfig {
  static Dio createDio({String baseUrl}) {
    return Dio(BaseOptions(
      connectTimeout: 5000,
      receiveTimeout: 5000,
      baseUrl: baseUrl,
    ));
  }

  static Dio addInterceptor({Dio dio, bool isRequireAuth, String token}) {
    return dio
      ..interceptors.add(InterceptorsWrapper(
          onError: (DioError dioError) => errorInterceptor(dioError),
          onRequest: (RequestOptions options) =>
              requestInterceptor(options, isRequireAuth, token),
          onResponse: (Response response) => responseInterceptor(response)));
  }

  static dynamic requestInterceptor(
      RequestOptions options, bool isRequireAuth, String token) async {
    options.responseType = ResponseType.json;

    if (isRequireAuth) {
      options.headers['token'] = "Bearer $token";
    }
    return options;
  }

  static dynamic responseInterceptor(Response response) async {
    if (response.headers.value("verifyToken") != null) {
      SharedPreferences pref = await SharedPreferences.getInstance();
      var verifyToken = pref.get("verifyToken");

      if (response.headers.value("verifyToken") == verifyToken) {
        return response;
      }
    }
  }

  static dynamic errorInterceptor(DioError error) async {
    var message = error.message;
    if (error.response != null) {
      if (error.response.statusCode == 401 ||
          error.message.contains("Token Expired")) {
        message = "401 error";
        // RoutesConfig.goOffAll(page: MainPage());
      } else {
        message = "Connection Server Error, please try again";
      }
    } else {
      if (error.message.toLowerCase().contains("failed host lookup")) {
        message = "No Internet Connection";
      } else {
        message = "Connection server error, please try again";
      }
    }
    return message;
  }
}
